##  Enabling Process Variants Import
To enable process variant synchronization:
  1. Go to the Basic Configuration tab in the integration configuration.
  2. Toggle on Import Variants.
  3. Click Save to apply the configuration.
  4. Click Sync Now to trigger synchronization.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3937e1d91fd64e0e8ec3a91da0cbd7fe_LowRes.png)
Enabling Process Variants Import
